import pytest
from risclog.logging import RiscLogger, get_logger


@pytest.fixture
def mock_environment(monkeypatch):
    monkeypatch.setenv('LOG_LEVEL', 'DEBUG')
    monkeypatch.setenv('logging_email_smtp_user', 'test_user@example.com')
    monkeypatch.setenv('logging_email_smtp_password', 'test_password')
    monkeypatch.setenv('logging_email_to', 'admin@example.com')
    monkeypatch.setenv('logging_email_smtp_server', 'smtp.example.com')


@pytest.fixture
def logger1() -> RiscLogger:
    return get_logger('test_logger_1')


@pytest.fixture
def logger2() -> RiscLogger:
    return get_logger('test_logger_2')



import logging
import sys
from unittest.mock import patch

import pytest
import risclog.logging
from structlog._config import BoundLoggerLazyProxy


def test_logger_initialization(
    logger1: risclog.logging.RiscLogger, logger2: risclog.logging.RiscLogger
) -> None:
    assert logger1.logger_name == 'test_logger_1'
    assert isinstance(logger1.logger, BoundLoggerLazyProxy)

    assert logger2.logger_name == 'test_logger_2'
    assert isinstance(logger2.logger, BoundLoggerLazyProxy)


@pytest.mark.asyncio
async def test_logging_levels_with_different_loggers(
    logger1: risclog.logging.RiscLogger,
    logger2: risclog.logging.RiscLogger,
    caplog,
) -> None:
    with caplog.at_level(logging.DEBUG):
        await logger1.debug('Test debug message logger1')
        assert 'Test debug message logger1' in caplog.text
        assert any(record.name == 'test_logger_1' for record in caplog.records)

    with caplog.at_level(logging.INFO):
        await logger2.info('Test info message logger2')
        assert 'Test info message logger2' in caplog.text
        assert any(record.name == 'test_logger_2' for record in caplog.records)

    assert not any(
        record.name == 'test_logger_2'
        and 'Test debug message logger1' in record.message
        for record in caplog.records
    )
    assert not any(
        record.name == 'test_logger_1'
        and 'Test info message logger2' in record.message
        for record in caplog.records
    )


def test_sync_log_decorator_with_different_loggers(logger1, logger2, caplog):
    @risclog.logging.RiscLogger.decorator
    def sample_sync_function_logger1(a, b):
        return a + b

    @risclog.logging.RiscLogger.decorator
    def sample_sync_function_logger2(a, b):
        return a - b

    with caplog.at_level(logging.INFO):
        result1 = sample_sync_function_logger1(3, 2)
    assert result1 == 5
    assert "Method called: \"sample_sync_function_logger1\"" in caplog.text

    with caplog.at_level(logging.INFO):
        result2 = sample_sync_function_logger2(3, 2)
    assert result2 == 1
    assert "Method called: \"sample_sync_function_logger2\"" in caplog.text

    assert not any(
        record.name == 'test_logger_2'
        and 'sample_sync_function_logger1' in record.message
        for record in caplog.records
    )
    assert not any(
        record.name == 'test_logger_1'
        and 'sample_sync_function_logger2' in record.message
        for record in caplog.records
    )


def test_structlog_logger_name(logger1, logger2, caplog):
    with caplog.at_level(logging.INFO):
        logger1.info('This is a message from logger 1')
        logger2.info('This is a message from logger 2')

    assert len(caplog.records) > 0

    logger_names = []
    for record in caplog.records:
        event_dict = record.msg if isinstance(record.msg, dict) else {}
        if 'logger' in event_dict:
            logger_names.append(event_dict['logger'])

    assert 'test_logger_1' in logger_names
    assert 'test_logger_2' in logger_names

    for name in logger_names:
        print(f'Logger name: {name}')


@pytest.mark.asyncio
async def test_async_log_decorator_with_different_loggers(
    logger1, logger2, caplog
):
    @risclog.logging.RiscLogger.decorator
    async def sample_async_function_logger1(a, b):
        return a + b

    @risclog.logging.RiscLogger.decorator
    async def sample_async_function_logger2(a, b):
        return a - b

    with caplog.at_level(logging.INFO):
        result1 = await sample_async_function_logger1(3, 2)

    assert result1 == 5
    assert "Method called: \"sample_async_function_logger1\"" in caplog.text

    with caplog.at_level(logging.INFO):
        result2 = await sample_async_function_logger2(3, 2)
    assert result2 == 1
    assert "Method called: \"sample_async_function_logger2\"" in caplog.text

    assert not any(
        record.name == 'test_logger_2'
        and 'sample_async_function_logger1' in record.message
        for record in caplog.records
    )
    assert not any(
        record.name == 'test_logger_1'
        and 'sample_async_function_logger2' in record.message
        for record in caplog.records
    )


def test_exception_to_string():
    try:
        raise ValueError('An error occurred')
    except Exception as exc:
        exc_string = risclog.logging.exception_to_string(exc)
        assert 'An error occurred' in exc_string


def test_debug_log(logger1, caplog):
    with caplog.at_level(logging.DEBUG):
        logger1.debug('This is a debug message')

    assert 'This is a debug message' in caplog.text
    assert 'test_logger' in caplog.text
    assert 'DEBUG' in caplog.text


def test_info_log(logger2, caplog):
    with caplog.at_level(logging.INFO):
        logger2.info('This is an info message')

    assert 'This is an info message' in caplog.text
    assert 'test_logger' in caplog.text
    assert 'INFO' in caplog.text


def test_warning_log(logger1, caplog):
    with caplog.at_level(logging.WARNING):
        logger1.warning('This is a warning message')

    assert 'This is a warning message' in caplog.text
    assert 'test_logger' in caplog.text
    assert 'WARNING' in caplog.text


def test_error_log(logger2, caplog):
    with caplog.at_level(logging.ERROR):
        logger2.error('This is an error message')

    assert 'This is an error message' in caplog.text
    assert 'test_logger' in caplog.text
    assert 'ERROR' in caplog.text


def test_critical_log(logger1, caplog):
    with caplog.at_level(logging.CRITICAL):
        logger1.critical('This is a critical message')

    assert 'This is a critical message' in caplog.text
    assert 'test_logger' in caplog.text
    assert 'CRITICAL' in caplog.text


def test_fatal_log(logger2, caplog):
    with caplog.at_level(logging.FATAL):
        logger2.fatal('This is a fatal message')

    assert 'This is a fatal message' in caplog.text
    assert 'test_logger' in caplog.text
    assert 'CRITICAL' in caplog.text


def test_exception_log(logger1, caplog):
    with caplog.at_level(logging.INFO):
        logger1.exception('This is a exception message')

    assert 'This is a exception message' in caplog.text
    assert 'test_logger' in caplog.text
    assert 'ERROR' in caplog.text


@pytest.mark.asyncio
async def test_async_logging_decorator(logger1, caplog):
    @logger1.decorator
    async def async_test_func(arg_0, arg_1):
        return f'Result: {arg_0 + arg_1}'

    with caplog.at_level(logging.INFO):
        result = await async_test_func(1, 2)

    assert result == 'Result: 3'

    log_records = [
        record for record in caplog.records if record.levelname == 'INFO'
    ]
    assert len(log_records) >= 2

    first_log = log_records[0].msg
    second_log = log_records[1].msg

    assert (
        'Method called: "async_test_func" with: "{\'arg_0\': 1, \'arg_1\': 2}"'
        in first_log['message']
    )
    assert (
        'Method "async_test_func" returned: "Result: 3"'
        in second_log['message']
    )


def test_sync_logging_decorator(logger1, caplog):
    @logger1.decorator()
    def sync_test_func(arg1, arg2):
        return f'Result: {arg1 + arg2}'

    with caplog.at_level(logging.INFO):
        result = sync_test_func(3, 4)

    assert result == 'Result: 7'

    log_records = [
        record for record in caplog.records if record.levelname == 'INFO'
    ]
    assert len(log_records) >= 2

    first_log = log_records[0].msg
    second_log = log_records[1].msg

    assert (
        'Method called: "sync_test_func" with: "{\'arg_0\': 3, \'arg_1\': 4}"'
        in first_log['message']
    )
    assert (
        'Method "sync_test_func" returned: "Result: 7"'
        in second_log['message']
    )


@patch('risclog.logging.smtp_email_send')
def test_exception_logging_with_email(mock_smtp_send, logger1, caplog):
    @logger1.decorator(send_email=True)
    def faulty_func():
        raise ValueError('This is an error')

    with caplog.at_level(logging.ERROR):
        with pytest.raises(ValueError, match='This is an error'):
            faulty_func()

    assert 'Exception occurred in method: faulty_func' in caplog.text
    assert 'This is an error' in caplog.text

    assert (
        mock_smtp_send.called
    ), 'smtp_email_send should be called when an exception occurs with send_email=True'
    mock_smtp_send.assert_called_once()

    args, kwargs = mock_smtp_send.call_args

    assert (
        len(args) == 0
    ), 'smtp_email_send should not be called with positional arguments'
    assert (
        len(kwargs) == 2
    ), 'smtp_email_send should be called with two keyword arguments'

    expected_message = 'Exception occurred in method: faulty_func'
    expected_logger_name = 'risclog.logging.tests.test_logger'
    assert (
        expected_message in kwargs['message']
    ), f"First keyword argument should be '{expected_message}'"
    assert (
        kwargs['logger_name'] == expected_logger_name
    ), f"Second keyword argument should be '{expected_logger_name}'"


@patch('risclog.logging.smtp_email_send')
@pytest.mark.asyncio
async def test_async_exception_logging_with_email(
    mock_smtp_send, logger1, caplog
):
    @logger1.decorator(send_email=True)
    async def faulty_async_func():
        raise ValueError('This is an async error')

    with caplog.at_level(logging.ERROR):
        with pytest.raises(ValueError, match='This is an async error'):
            await faulty_async_func()

    assert 'Exception occurred in method: faulty_async_func' in caplog.text
    assert 'This is an async error' in caplog.text

    assert (
        mock_smtp_send.called
    ), 'smtp_email_send should be called when an exception occurs in async function with send_email=True'
    mock_smtp_send.assert_called_once()
    args, kwargs = mock_smtp_send.call_args

    assert (
        len(args) == 0
    ), 'smtp_email_send should not be called with positional arguments'
    assert (
        len(kwargs) == 2
    ), 'smtp_email_send should be called with two keyword arguments'

    assert (
        'This is an async error' in kwargs['message']
    ), 'The error message should be in the email content'
    assert (
        'risclog.logging' in kwargs['logger_name']
    ), 'Logger name should be passed to the smtp_email_send function'


def test_rename_event_to_message():
    event_dict = {
        'event': 'This is an event message',
        'level': 'info',
        'referer': 'https://example.com',
        'user': 'test_user',
    }
    expected_dict = {
        'level': 'info',
        'user': 'test_user',
        'message': 'This is an event message',
        'referer': 'https://example.com',
    }
    result_dict = risclog.logging.rename_event_to_message(
        None, None, event_dict
    )

    assert (
        result_dict == expected_dict
    ), f'Expected {expected_dict} but got {result_dict}'


def test_no_event_key():
    event_dict = {
        'level': 'info',
        'user': 'test_user',
        'referer': 'https://example.com',
    }
    expected_dict = {
        'level': 'info',
        'user': 'test_user',
        'referer': 'https://example.com',
    }
    result_dict = risclog.logging.rename_event_to_message(
        None, None, event_dict
    )

    assert (
        result_dict == expected_dict
    ), f'Expected {expected_dict} but got {result_dict}'


def test_empty_dict():
    event_dict = {}
    expected_dict = {}
    result_dict = risclog.logging.rename_event_to_message(
        None, None, event_dict
    )

    assert (
        result_dict == expected_dict
    ), f'Expected {expected_dict} but got {result_dict}'


def test_handle_keyboard_interrupt(logger1):
    with patch('sys.__excepthook__') as mock_excepthook:
        risclog.logging.RiscLogger._configure_logger()
        sys.excepthook(KeyboardInterrupt, None, None)
        mock_excepthook.assert_called_once_with(KeyboardInterrupt, None, None)


def test_inline_and_decorator_have_same_id_in_logs(logger1, caplog):
    @logger1.decorator()
    def test_func():
        logger1.info('This is a message from the decorator')

    with caplog.at_level(logging.INFO):
        test_func()

    log_records = [
        record for record in caplog.records if record.levelname == 'INFO'
    ]
    assert len(log_records) == 3
    assert len({r.msg['__id'] for r in log_records}) == 1



import asyncio
import inspect
import logging
import os
import smtplib
import sys
import traceback
from concurrent.futures import ThreadPoolExecutor
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from functools import partial, wraps
from pathlib import Path
from typing import Coroutine

import structlog
from structlog.types import Processor


def rename_event_to_message(_, __, event_dict):
    if 'event' in event_dict:
        event_dict['message'] = event_dict.pop('event')
    keys_at_end = ['referer']
    sorted_keys = sorted(
        event_dict.keys(), key=lambda x: (x in keys_at_end, x)
    )
    sorted_dict = {k: event_dict[k] for k in sorted_keys}
    return sorted_dict


class RiscLogger:
    def __init__(self, name: str = None) -> None:
        self.logger = structlog.stdlib.get_logger(name)
        self.logger_name = name

    def __new__(cls, *args, **kwargs):
        cls._configure_logger()
        instance = super().__new__(cls)

        return instance

    @classmethod
    def _configure_logger(cls):
        LEVELS = {
            'CRITICAL': 50,
            'FATAL': 50,
            'ERROR': 40,
            'WARNING': 30,
            'WARN': 30,
            'INFO': 20,
            'DEBUG': 10,
        }

        log_level = LEVELS.get(os.getenv('LOG_LEVEL'), 20)

        timestamper = structlog.processors.TimeStamper(fmt='%Y-%m-%d %H:%M:%S')
        shared_processors: list[Processor] = [
            structlog.contextvars.merge_contextvars,
            structlog.stdlib.add_logger_name,
            structlog.stdlib.add_log_level,
            structlog.stdlib.PositionalArgumentsFormatter(),
            structlog.stdlib.ExtraAdder(),
            timestamper,
            structlog.processors.StackInfoRenderer(),
            rename_event_to_message,
        ]

        structlog.configure(
            logger_factory=structlog.stdlib.LoggerFactory(),
            processors=shared_processors
            + [
                structlog.stdlib.ProcessorFormatter.wrap_for_formatter,
            ],
            wrapper_class=structlog.stdlib.BoundLogger,
            cache_logger_on_first_use=True,
        )

        log_renderer: structlog.types.Processor
        log_renderer = structlog.dev.ConsoleRenderer()
        formatter = structlog.stdlib.ProcessorFormatter(
            foreign_pre_chain=shared_processors,
            processors=[
                structlog.stdlib.ProcessorFormatter.remove_processors_meta,
                log_renderer,
            ],
        )

        # set logger Level from asyncio package to WARNING
        logging.getLogger('asyncio').setLevel(logging.WARNING)
        if not logging.getLogger().hasHandlers():
            handler = logging.StreamHandler()
            handler.setFormatter(formatter)
            root_logger = logging.getLogger()
            root_logger.addHandler(handler)
            root_logger.setLevel(log_level)

        all_logger = list(logging.Logger.manager.loggerDict.keys())
        all_logger.extend(['uvicorn', 'uvicorn.error'])

        for _log in list(set(all_logger)):
            logging.getLogger(_log).handlers.clear()
            logging.getLogger(_log).propagate = True

        logging.getLogger('uvicorn.access').handlers.clear()
        logging.getLogger('uvicorn.access').propagate = False

        def handle_exception(exc_type, exc_value, exc_traceback):
            if issubclass(exc_type, KeyboardInterrupt):
                sys.__excepthook__(exc_type, exc_value, exc_traceback)
                return False

        sys.excepthook = handle_exception

    async def _async_log(
        self,
        level: str,
        msg: str,
        sender: str,
        function_id: int,
        *args,
        **kwargs,
    ) -> Coroutine:
        await asyncio.sleep(0)
        func = getattr(self.logger, level.lower())
        sender = kwargs.get('sender') if kwargs.get('sender') else sender
        kwargs = {**{'__id': function_id, '__sender': sender}, **kwargs}
        func(msg, *args, **kwargs)

    def _log(
        self,
        level: str,
        msg: str,
        sender: str = 'inline',
        method_id: int = None,
        *args,
        **kwargs,
    ) -> Coroutine:
        try:
            loop = asyncio.get_running_loop()
        except RuntimeError:
            loop = None

        if method_id:
            function_id = method_id
        else:
            caller_frame = inspect.stack()[2]
            caller_name = caller_frame.function
            function_id = id(caller_name)

        if loop and loop.is_running():

            return self._async_log(
                level=level,
                msg=msg,
                sender=sender,
                function_id=function_id,
                *args,
                **kwargs,
            )
        else:
            return asyncio.run(
                self._async_log(
                    level=level,
                    msg=msg,
                    sender=sender,
                    function_id=function_id,
                    *args,
                    **kwargs,
                )
            )

    def debug(
        self, msg: str = None, method_id: int = None, *args, **kwargs
    ) -> Coroutine:
        return self._log(
            level='debug', msg=msg, method_id=method_id, *args, **kwargs
        )

    def info(
        self, msg: str = None, method_id: int = None, *args, **kwargs
    ) -> Coroutine:
        return self._log(
            level='info', msg=msg, method_id=method_id, *args, **kwargs
        )

    def warning(
        self, msg: str = None, method_id: int = None, *args, **kwargs
    ) -> Coroutine:
        return self._log(
            level='warning', msg=msg, method_id=method_id, *args, **kwargs
        )

    def fatal(
        self, msg: str = None, method_id: int = None, *args, **kwargs
    ) -> Coroutine:
        return self._log(
            level='fatal', msg=msg, method_id=method_id, *args, **kwargs
        )

    def critical(
        self, msg: str = None, method_id: int = None, *args, **kwargs
    ) -> Coroutine:
        return self._log(
            level='critical', msg=msg, method_id=method_id, *args, **kwargs
        )

    def exception(
        self, msg: str = None, method_id: int = None, *args, **kwargs
    ) -> Coroutine:
        return self._log(
            level='error', msg=msg, method_id=method_id, *args, **kwargs
        )

    def error(
        self, msg: str = None, method_id: int = None, *args, **kwargs
    ) -> Coroutine:
        return self._log(
            level='error', msg=msg, method_id=method_id, *args, **kwargs
        )

    @classmethod
    def decorator(cls, method=None, send_email=False):
        if method is None:
            return lambda m: cls.decorator(m, send_email)

        method_id = id(method.__name__)
        logger = cls(name=method.__module__)

        if inspect.iscoroutinefunction(method):

            @wraps(method)
            async def async_wrapper(*args, **kwargs):
                try:
                    script = Path(inspect.getfile(method)).name
                    structlog.contextvars.bind_contextvars(
                        _function=method.__name__,
                        _script=script,
                    )

                    frame = inspect.currentframe()
                    _, _, _, frame_values = inspect.getargvalues(frame)
                    args_dict = {f'arg_{i}': arg for i, arg in enumerate(args)}
                    params = {**args_dict, **frame_values.get('kwargs')}

                    if params:
                        await logger.info(
                            f'Method called: "{method.__name__}" with: "{params}"',
                            sender='async_logging_decorator',
                            method_id=method_id,
                        )
                    else:
                        await logger.info(
                            f'Method "{method.__name__}" called with no arguments.',
                            sender='async_logging_decorator',
                            method_id=method_id,
                        )

                    value = await method(*args, **kwargs)
                    await logger.info(
                        f'Method "{method.__name__}" returned: "{value}"',
                        sender='async_logging_decorator',
                        method_id=method_id,
                    )
                    return value
                except Exception as exc:
                    message = f'Exception occurred in method: {method.__name__}, exception: {exc}'
                    if send_email:
                        with ThreadPoolExecutor() as executor:
                            message = f'{message}\n\n\n{exception_to_string(excp=exc)}'
                            executor.submit(
                                partial(
                                    smtp_email_send,
                                    message=message,
                                    logger_name=logger.logger_name,
                                )
                            )
                    await logger.exception(
                        message,
                        sender='async_logging_decorator',
                        method_id=method_id,
                    )
                    raise exc
                finally:
                    structlog.contextvars.unbind_contextvars(
                        '_function', '_script'
                    )

            return async_wrapper
        else:

            @wraps(method)
            def sync_wrapper(*args, **kwargs):
                try:
                    script = Path(inspect.getfile(method)).name
                    structlog.contextvars.bind_contextvars(
                        _function=method.__name__,
                        _script=script,
                    )

                    frame = inspect.currentframe()
                    _, _, _, frame_values = inspect.getargvalues(frame)
                    args_dict = {f'arg_{i}': arg for i, arg in enumerate(args)}
                    params = {**args_dict, **frame_values.get('kwargs')}

                    if params:
                        logger.info(
                            f'Method called: "{method.__name__}" with: "{params}"',
                            sender='logging_decorator',
                            method_id=method_id,
                        )
                    else:
                        logger.info(
                            f'Method "{method.__name__}" called with no arguments.',
                            sender='logging_decorator',
                            method_id=method_id,
                        )

                    value = method(*args, **kwargs)
                    logger.info(
                        f'Method "{method.__name__}" returned: "{value}"',
                        sender='logging_decorator',
                        method_id=method_id,
                    )
                    return value
                except Exception as exc:
                    message = f'Exception occurred in method: {method.__name__}, exception: {exc}'
                    if send_email:
                        with ThreadPoolExecutor() as executor:
                            message = f'{message}\n\n\n{exception_to_string(excp=exc)}'
                            executor.submit(
                                partial(
                                    smtp_email_send,
                                    message=message,
                                    logger_name=logger.logger_name,
                                )
                            )
                    logger.exception(
                        message,
                        sender='logging_decorator',
                        method_id=method_id,
                    )
                    raise exc
                finally:
                    structlog.contextvars.unbind_contextvars(
                        '_function', '_script'
                    )

            return sync_wrapper


def get_logger(name: str = None):
    if not name:
        frm = inspect.stack()[1]
        mod = inspect.getmodule(frm[0])

        if not hasattr(mod, __name__):
            name = mod.__name__
        else:
            name = logging.getLogger().name
    return RiscLogger(name=name)


def exception_to_string(excp):
    stack = traceback.extract_stack()[:-3] + traceback.extract_tb(
        excp.__traceback__
    )
    pretty = traceback.format_list(stack)
    return ''.join(pretty) + '\n  {} {}'.format(excp.__class__, excp)


def smtp_email_send(message: str, logger_name: str) -> None:
    smtp_user = os.getenv('LOGGING_EMAIL_SMTP_USER')
    smtp_password = os.getenv('LOGGING_EMAIL_SMTP_PASSWORD')
    email_to = os.getenv('LOGGING_EMAIL_TO')
    smtp_server = os.getenv('LOGGING_EMAIL_SMTP_SERVER')

    if smtp_user and smtp_password and email_to and smtp_server:
        # Email server setup
        smtp_user = smtp_user
        smtp_password = smtp_password

        # Create the email message
        email_message = MIMEMultipart()
        email_message['From'] = smtp_user
        email_message['To'] = email_to
        email_message['Subject'] = f'Error in {logger_name}'
        email_message.attach(MIMEText(message, 'plain'))

        # Send the email
        with smtplib.SMTP(host=smtp_server, port=465) as smtp:
            smtp.ehlo()
            smtp.starttls()
            smtp.login(smtp_user, smtp_password)
            smtp.send_message(email_message)
    else:
        logger = get_logger(name=logger_name)
        logger.error(
            'Emails cannot be sent because one or more environment variables are not set!'
        )



#!/usr/bin/env python

"""The setup script."""

from setuptools import find_packages, setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('CHANGES.rst') as history_file:
    history = history_file.read()

setup(
    author='riscLOG Solution GmbH',
    author_email='info@risclog.de',
    python_requires='>=3.8',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: German',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    description='A logger based on structlog',
    install_requires=[
        # Add your dependencies here
        'structlog',
    ],
    extras_require={
        'docs': [
            'Sphinx',
        ],
        'test': [
            'pytest-cache',
            'pytest-cov',
            'pytest-flake8',
            'pytest-rerunfailures',
            'pytest-sugar',
            'pytest',
            'coverage',
            # https://github.com/PyCQA/flake8/issues/1419#issuecomment-947243876
            'flake8<4',
            'mock',
            'requests',
            'httpx',
            'pytest-asyncio',
        ],
    },
    license='MIT license',
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='risclog.logging',
    name='risclog.logging',
    packages=find_packages('src'),
    namespace_packages=['risclog'],
    package_dir={'': 'src'},
    url='https://github.com/risclog-solution/risclog.logging',
    version='1.2.0',
    zip_safe=False,
)
